==> web-fw2_2_2.zip: web-fw2_2_2/j2src/weber/org/itscool/weber/tag/RadioTag.java <==
package org.itscool.weber.tag;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.BodyContent;

import org.itscool.commons.util.TagUtil;
import org.itscool.weber.action.Globals;

/**
 * HTML&lt;inut type="radio"&gt;^O𐶐^OłB<BR>
 * nameŎw肵BeanɑΉvpeB̒lɂȂ܂B<BR>
 * namew肵ȂꍇnulllԂ܂B<BR>
 *isturts̏ꍇStrutsݒt@Cł̃tH[Ɋ֘AÂꂽBean
 * ɑΉvpeB̒lɂȂ܂B)<BR>
 * x\̓^Õ{fBƂċLq鎖ł܂B<BR>
 * <BR>
 *yz<BR>
 * name ̃tB[h̏lݒ肷ۂɎgBean̖OiK{j<BR>
 * property ̃WI{^ɑΉp[^iK{j<BR>
 * value Tu~bgɑMl(K{)<BR>
 * selected WI^Ȍ\sہAftHgݒw肷ꍇ
 *          truew肵ĂB<BR>
 *
 * @author KANO
 * @since jdk1.4.1
 * @version 1.00A 2004/11/1
*/
public class RadioTag extends HtmlBodyTag {
    protected String text = null;    //{fBɕ\eLXg
    
    /**
     * ftHg̑Ilݒ肵܂B
    */
    protected boolean selected;
    
    /**
     * @return selected
     */
    public boolean getSelected() {
        return selected;
    }
    /**
     * @param selected selected ݒ肵܂B
     */
    public void setSelected(boolean selected) {
        this.selected = selected;
    }
    
    /**
     * scopew肳ĂȂꍇ́ȀŃIuWFNg܂B
     * request, session, context̏
    */
    public int doStartTag() throws JspException {
        StringBuffer inputTag = new StringBuffer("<input type=\"radio\" ");
        if( htmlname != null && htmlname.length() > 0 ){
			inputTag.append( TagUtil.createAttribute("name", htmlname) );
        }else{
        	inputTag.append( TagUtil.createAttribute("name", property) );
        }
        inputTag.append( TagUtil.createAttribute(pageContext, name, 
            property, scope, "value", value) );
		
		//SELECT^OɃZbgꂽBeañvpeB܂B
		String selectName = (String) pageContext.getRequest().getAttribute(
			Globals.SELECT_TAG_NAME);
		Object selectValue = TagUtil.findProperty( pageContext, 
			Globals.SELECT_TAG_VALUE, selectName, scope);
        	
        
        //NGXgɃZbgꂽBeañvpeB܂B
        //YvpeB݂ꍇcheckedIvVt܂B
        Object beanValue = TagUtil.findProperty(pageContext, 
            name, property, scope);
        
		inputTag.append(TagUtil.createAttribute("style", style));
		inputTag.append(TagUtil.createBoolAttribute("readonly", readonly));
		inputTag.append(TagUtil.createBoolAttribute("disabled", disabled));
		inputTag.append(TagUtil.createBoolAttribute("class", csClass));
        inputTag.append(this.createJavaScriptTag());
        
        //ELΉ
        value = TagUtil.findValue(pageContext, value, scope).toString();
		
        if (TagUtil.isCheckedValue(selectValue, value) ||
		TagUtil.isCheckedValue(selectValue, beanValue.toString() )) {
			inputTag.append("checked>");
		} else if(( selectValue==null || selectValue.equals("") )
		&& selected ){
			inputTag.append("checked>");
		} else {
			inputTag.append(">");
		}
        
        try{
            pageContext.getOut().print(inputTag.toString());
        }catch( Exception e ){
            throw new JspException(e.getMessage());
        }
        
        return EVAL_BODY_AGAIN; 
    }
    
	public int doAfterBody() throws JspException{
		try {
			BodyContent body = getBodyContent();
			body.writeOut(getPreviousOut());
			body.clearBody();
		} catch (Exception e) {
			throw new JspException(e.getMessage());
		}
		return SKIP_BODY;
	}
    
	public int doEndTag()  throws JspException{
		try {
			pageContext.getOut().print("</input>");
		} catch (Exception e) {
			throw new JspException(e.getMessage());
		}
		return EVAL_PAGE;
	}
}

==> web-fw3_0_2.zip: web-fw3_0_2/j2src/weber/org/itscool/weber/tag/RadioTag.java <==
package org.itscool.weber.tag;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.BodyContent;

import org.itscool.commons.util.JspTagUtil;
import org.itscool.weber.action.Globals;

/**
 * HTML&lt;inut type="radio"&gt;^O𐶐^OłB<BR>
 * nameŎw肵BeanɑΉvpeB̒lɂȂ܂B<BR>
 * namew肵ȂꍇnulllԂ܂B<BR>
 *isturts̏ꍇStrutsݒt@Cł̃tH[Ɋ֘AÂꂽBean
 * ɑΉvpeB̒lɂȂ܂B)<BR>
 * x\̓^Õ{fBƂċLq鎖ł܂B<BR>
 * <BR>
 *yz<BR>
 * name ̃tB[h̏lݒ肷ۂɎgBean̖OiK{j<BR>
 * property ̃WI{^ɑΉp[^iK{j<BR>
 * value Tu~bgɑMl(K{)<BR>
 * selected WI^Ȍ\sہAftHgݒw肷ꍇ
 *          truew肵ĂB<BR>
 *
 * @author KANO
 * @since jdk1.4.1
 * @version 1.00A 2004/11/1
*/
public class RadioTag extends HtmlBodyTag {
    protected String text = null;    //{fBɕ\eLXg
    
    /**
     * ftHg̑Ilݒ肵܂B
    */
    protected boolean selected;
    
    /**
     * @return selected
     */
    public boolean getSelected() {
        return selected;
    }
    /**
     * @param selected selected ݒ肵܂B
     */
    public void setSelected(boolean selected) {
        this.selected = selected;
    }
    
    /**
     * scopew肳ĂȂꍇ́ȀŃIuWFNg܂B
     * request, session, context̏
    */
    public int doStartTag() throws JspException {
        StringBuffer inputTag = new StringBuffer("<input type=\"radio\" ");
        if( htmlname != null && htmlname.length() > 0 ){
			inputTag.append( JspTagUtil.createAttribute("name", htmlname) );
        }else{
        	inputTag.append( JspTagUtil.createAttribute("name", property) );
        }
        inputTag.append( JspTagUtil.createAttribute(pageContext, name, 
            property, scope, "value", value) );
		
		//SELECT^OɃZbgꂽBeañvpeB܂B
		String selectName = (String) pageContext.getRequest().getAttribute(
			Globals.SELECT_TAG_NAME);
		Object selectValue = JspTagUtil.findProperty( pageContext, 
			Globals.SELECT_TAG_VALUE, selectName, scope);
        	
        
        //NGXgɃZbgꂽBeañvpeB܂B
        //YvpeB݂ꍇcheckedIvVt܂B
        Object beanValue = JspTagUtil.findProperty(pageContext, 
            name, property, scope);
        
		inputTag.append(JspTagUtil.createAttribute("style", style));
		inputTag.append(JspTagUtil.createBoolAttribute("readonly", readonly));
		inputTag.append(JspTagUtil.createBoolAttribute("disabled", disabled));
		inputTag.append(JspTagUtil.createBoolAttribute("class", csClass));
        inputTag.append(this.createJavaScriptTag());
        
        //ELΉ
        value = JspTagUtil.findValue(pageContext, value, scope).toString();
		
        if (JspTagUtil.isCheckedValue(selectValue, value) ||
		JspTagUtil.isCheckedValue(selectValue, beanValue.toString() )) {
			inputTag.append("checked>");
		} else if(( selectValue==null || selectValue.equals("") )
		&& selected ){
			inputTag.append("checked>");
		} else {
			inputTag.append(">");
		}
        
        try{
            pageContext.getOut().print(inputTag.toString());
        }catch( Exception e ){
            throw new JspException(e.getMessage());
        }
        
        return EVAL_BODY_AGAIN; 
    }
    
	public int doAfterBody() throws JspException{
		try {
			BodyContent body = getBodyContent();
			body.writeOut(getPreviousOut());
			body.clearBody();
		} catch (Exception e) {
			throw new JspException(e.getMessage());
		}
		return SKIP_BODY;
	}
    
	public int doEndTag()  throws JspException{
		try {
			pageContext.getOut().print("</input>");
		} catch (Exception e) {
			throw new JspException(e.getMessage());
		}
		return EVAL_PAGE;
	}
}
